Class: Aws::Panorama::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Panorama::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-panorama/client.rb,
sig/client.rbs
Overview
An API client for Panorama. To construct a client, you need to configure a :region and :credentials.
client = Aws::Panorama::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateApplicationInstanceResponseSuccess, _CreateJobForDevicesResponseSuccess, _CreateNodeFromTemplateJobResponseSuccess, _CreatePackageImportJobResponseSuccess, _CreatePackageResponseSuccess, _DeleteDeviceResponseSuccess, _DeletePackageResponseSuccess, _DeregisterPackageVersionResponseSuccess, _DescribeApplicationInstanceDetailsResponseSuccess, _DescribeApplicationInstanceResponseSuccess, _DescribeDeviceJobResponseSuccess, _DescribeDeviceResponseSuccess, _DescribeNodeFromTemplateJobResponseSuccess, _DescribeNodeResponseSuccess, _DescribePackageImportJobResponseSuccess, _DescribePackageResponseSuccess, _DescribePackageVersionResponseSuccess, _ListApplicationInstanceDependenciesResponseSuccess, _ListApplicationInstanceNodeInstancesResponseSuccess, _ListApplicationInstancesResponseSuccess, _ListDevicesJobsResponseSuccess, _ListDevicesResponseSuccess, _ListNodeFromTemplateJobsResponseSuccess, _ListNodesResponseSuccess, _ListPackageImportJobsResponseSuccess, _ListPackagesResponseSuccess, _ListTagsForResourceResponseSuccess, _ProvisionDeviceResponseSuccess, _RegisterPackageVersionResponseSuccess, _RemoveApplicationInstanceResponseSuccess, _SignalApplicationInstanceNodeInstancesResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateDeviceMetadataResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_application_instance(params = {}) ⇒ Types::CreateApplicationInstanceResponse
Creates an application instance and deploys it to a device.
-
#create_job_for_devices(params = {}) ⇒ Types::CreateJobForDevicesResponse
Creates a job to run on a device.
-
#create_node_from_template_job(params = {}) ⇒ Types::CreateNodeFromTemplateJobResponse
Creates a camera stream node.
-
#create_package(params = {}) ⇒ Types::CreatePackageResponse
Creates a package and storage location in an Amazon S3 access point.
-
#create_package_import_job(params = {}) ⇒ Types::CreatePackageImportJobResponse
Imports a node package.
-
#delete_device(params = {}) ⇒ Types::DeleteDeviceResponse
Deletes a device.
-
#delete_package(params = {}) ⇒ Struct
Deletes a package.
-
#deregister_package_version(params = {}) ⇒ Struct
Deregisters a package version.
-
#describe_application_instance(params = {}) ⇒ Types::DescribeApplicationInstanceResponse
Returns information about an application instance on a device.
-
#describe_application_instance_details(params = {}) ⇒ Types::DescribeApplicationInstanceDetailsResponse
Returns information about an application instance's configuration manifest.
-
#describe_device(params = {}) ⇒ Types::DescribeDeviceResponse
Returns information about a device.
-
#describe_device_job(params = {}) ⇒ Types::DescribeDeviceJobResponse
Returns information about a device job.
-
#describe_node(params = {}) ⇒ Types::DescribeNodeResponse
Returns information about a node.
-
#describe_node_from_template_job(params = {}) ⇒ Types::DescribeNodeFromTemplateJobResponse
Returns information about a job to create a camera stream node.
-
#describe_package(params = {}) ⇒ Types::DescribePackageResponse
Returns information about a package.
-
#describe_package_import_job(params = {}) ⇒ Types::DescribePackageImportJobResponse
Returns information about a package import job.
-
#describe_package_version(params = {}) ⇒ Types::DescribePackageVersionResponse
Returns information about a package version.
-
#list_application_instance_dependencies(params = {}) ⇒ Types::ListApplicationInstanceDependenciesResponse
Returns a list of application instance dependencies.
-
#list_application_instance_node_instances(params = {}) ⇒ Types::ListApplicationInstanceNodeInstancesResponse
Returns a list of application node instances.
-
#list_application_instances(params = {}) ⇒ Types::ListApplicationInstancesResponse
Returns a list of application instances.
-
#list_devices(params = {}) ⇒ Types::ListDevicesResponse
Returns a list of devices.
-
#list_devices_jobs(params = {}) ⇒ Types::ListDevicesJobsResponse
Returns a list of jobs.
-
#list_node_from_template_jobs(params = {}) ⇒ Types::ListNodeFromTemplateJobsResponse
Returns a list of camera stream node jobs.
-
#list_nodes(params = {}) ⇒ Types::ListNodesResponse
Returns a list of nodes.
-
#list_package_import_jobs(params = {}) ⇒ Types::ListPackageImportJobsResponse
Returns a list of package import jobs.
-
#list_packages(params = {}) ⇒ Types::ListPackagesResponse
Returns a list of packages.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a resource.
-
#provision_device(params = {}) ⇒ Types::ProvisionDeviceResponse
Creates a device and returns a configuration archive.
-
#register_package_version(params = {}) ⇒ Struct
Registers a package version.
-
#remove_application_instance(params = {}) ⇒ Struct
Removes an application instance.
-
#signal_application_instance_node_instances(params = {}) ⇒ Types::SignalApplicationInstanceNodeInstancesResponse
Signal camera nodes to stop or resume.
-
#tag_resource(params = {}) ⇒ Struct
Tags a resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
-
#update_device_metadata(params = {}) ⇒ Types::UpdateDeviceMetadataResponse
Updates a device's metadata.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-panorama/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2168 2169 2170 |
# File 'lib/aws-sdk-panorama/client.rb', line 2168 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2171 2172 2173 |
# File 'lib/aws-sdk-panorama/client.rb', line 2171 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 |
# File 'lib/aws-sdk-panorama/client.rb', line 2141 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Panorama') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-panorama' context[:gem_version] = '1.59.0' Seahorse::Client::Request.new(handlers, context) end |
#create_application_instance(params = {}) ⇒ Types::CreateApplicationInstanceResponse
Creates an application instance and deploys it to a device.
86 |
# File 'sig/client.rbs', line 86
def create_application_instance: (
|
#create_job_for_devices(params = {}) ⇒ Types::CreateJobForDevicesResponse
Creates a job to run on a device. A job can update a device's software or reboot it.
107 |
# File 'sig/client.rbs', line 107
def create_job_for_devices: (
|
#create_node_from_template_job(params = {}) ⇒ Types::CreateNodeFromTemplateJobResponse
Creates a camera stream node.
124 |
# File 'sig/client.rbs', line 124
def create_node_from_template_job: (
|
#create_package(params = {}) ⇒ Types::CreatePackageResponse
Creates a package and storage location in an Amazon S3 access point.
147 |
# File 'sig/client.rbs', line 147
def create_package: (
|
#create_package_import_job(params = {}) ⇒ Types::CreatePackageImportJobResponse
Imports a node package.
158 |
# File 'sig/client.rbs', line 158
def create_package_import_job: (
|
#delete_device(params = {}) ⇒ Types::DeleteDeviceResponse
Deletes a device.
191 |
# File 'sig/client.rbs', line 191
def delete_device: (
|
#delete_package(params = {}) ⇒ Struct
Deletes a package.
s3:DeleteObject in
addition to permissions for the AWS Panorama API.
200 |
# File 'sig/client.rbs', line 200
def delete_package: (
|
#deregister_package_version(params = {}) ⇒ Struct
Deregisters a package version.
210 |
# File 'sig/client.rbs', line 210
def deregister_package_version: (
|
#describe_application_instance(params = {}) ⇒ Types::DescribeApplicationInstanceResponse
Returns information about an application instance on a device.
238 |
# File 'sig/client.rbs', line 238
def describe_application_instance: (
|
#describe_application_instance_details(params = {}) ⇒ Types::DescribeApplicationInstanceDetailsResponse
Returns information about an application instance's configuration manifest.
255 |
# File 'sig/client.rbs', line 255
def describe_application_instance_details: (
|
#describe_device(params = {}) ⇒ Types::DescribeDeviceResponse
Returns information about a device.
284 |
# File 'sig/client.rbs', line 284
def describe_device: (
|
#describe_device_job(params = {}) ⇒ Types::DescribeDeviceJobResponse
Returns information about a device job.
302 |
# File 'sig/client.rbs', line 302
def describe_device_job: (
|
#describe_node(params = {}) ⇒ Types::DescribeNodeResponse
Returns information about a node.
325 |
# File 'sig/client.rbs', line 325
def describe_node: (
|
#describe_node_from_template_job(params = {}) ⇒ Types::DescribeNodeFromTemplateJobResponse
Returns information about a job to create a camera stream node.
347 |
# File 'sig/client.rbs', line 347
def describe_node_from_template_job: (
|
#describe_package(params = {}) ⇒ Types::DescribePackageResponse
Returns information about a package.
364 |
# File 'sig/client.rbs', line 364
def describe_package: (
|
#describe_package_import_job(params = {}) ⇒ Types::DescribePackageImportJobResponse
Returns information about a package import job.
384 |
# File 'sig/client.rbs', line 384
def describe_package_import_job: (
|
#describe_package_version(params = {}) ⇒ Types::DescribePackageVersionResponse
Returns information about a package version.
403 |
# File 'sig/client.rbs', line 403
def describe_package_version: (
|
#list_application_instance_dependencies(params = {}) ⇒ Types::ListApplicationInstanceDependenciesResponse
Returns a list of application instance dependencies.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
417 |
# File 'sig/client.rbs', line 417
def list_application_instance_dependencies: (
|
#list_application_instance_node_instances(params = {}) ⇒ Types::ListApplicationInstanceNodeInstancesResponse
Returns a list of application node instances.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
430 |
# File 'sig/client.rbs', line 430
def list_application_instance_node_instances: (
|
#list_application_instances(params = {}) ⇒ Types::ListApplicationInstancesResponse
Returns a list of application instances.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
443 |
# File 'sig/client.rbs', line 443
def list_application_instances: (
|
#list_devices(params = {}) ⇒ Types::ListDevicesResponse
Returns a list of devices.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
457 |
# File 'sig/client.rbs', line 457
def list_devices: (
|
#list_devices_jobs(params = {}) ⇒ Types::ListDevicesJobsResponse
Returns a list of jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
473 |
# File 'sig/client.rbs', line 473
def list_devices_jobs: (
|
#list_node_from_template_jobs(params = {}) ⇒ Types::ListNodeFromTemplateJobsResponse
Returns a list of camera stream node jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
486 |
# File 'sig/client.rbs', line 486
def list_node_from_template_jobs: (
|
#list_nodes(params = {}) ⇒ Types::ListNodesResponse
Returns a list of nodes.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
498 |
# File 'sig/client.rbs', line 498
def list_nodes: (
|
#list_package_import_jobs(params = {}) ⇒ Types::ListPackageImportJobsResponse
Returns a list of package import jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
515 |
# File 'sig/client.rbs', line 515
def list_package_import_jobs: (
|
#list_packages(params = {}) ⇒ Types::ListPackagesResponse
Returns a list of packages.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
527 |
# File 'sig/client.rbs', line 527
def list_packages: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a resource.
538 |
# File 'sig/client.rbs', line 538
def list_tags_for_resource: (
|
#provision_device(params = {}) ⇒ Types::ProvisionDeviceResponse
Creates a device and returns a configuration archive. The
configuration archive is a ZIP file that contains a provisioning
certificate that is valid for 5 minutes. Name the configuration
archive certificates-omni_device-name.zip and transfer it to the
device within 5 minutes. Use the included USB storage device and
connect it to the USB 3.0 port next to the HDMI output.
552 |
# File 'sig/client.rbs', line 552
def provision_device: (
|
#register_package_version(params = {}) ⇒ Struct
Registers a package version.
570 |
# File 'sig/client.rbs', line 570
def register_package_version: (
|
#remove_application_instance(params = {}) ⇒ Struct
Removes an application instance.
583 |
# File 'sig/client.rbs', line 583
def remove_application_instance: (
|
#signal_application_instance_node_instances(params = {}) ⇒ Types::SignalApplicationInstanceNodeInstancesResponse
Signal camera nodes to stop or resume.
593 |
# File 'sig/client.rbs', line 593
def signal_application_instance_node_instances: (
|
#tag_resource(params = {}) ⇒ Struct
Tags a resource.
608 |
# File 'sig/client.rbs', line 608
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource.
618 |
# File 'sig/client.rbs', line 618
def untag_resource: (
|
#update_device_metadata(params = {}) ⇒ Types::UpdateDeviceMetadataResponse
Updates a device's metadata.
629 |
# File 'sig/client.rbs', line 629
def update_device_metadata: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2161 2162 2163 |
# File 'lib/aws-sdk-panorama/client.rb', line 2161 def waiter_names [] end |